@@ -1,23 +1,34 @@
-from collections import OrderedDict
 from argparse import ArgumentParser, RawTextHelpFormatter
+from collections import OrderedDict
+import logging
+import os
 
-from catalyst.contrib.scripts import project_embeddings, \
-    check_index_model, create_index_model
+from catalyst.contrib.scripts import find_thresholds
 
-COMMANDS = OrderedDict(
-    [
-        ("check-index-model", check_index_model),
-        ("create-index-model", create_index_model),
-        ("project-embeddings", project_embeddings)
-    ]
-)
+logger = logging.getLogger(__name__)
+
+COMMANDS = OrderedDict([("find-thresholds", find_thresholds)])
+
+try:
+    import nmslib  # noqa: F401
+    from catalyst.contrib.scripts import check_index_model, create_index_model
+
+    COMMANDS["check-index-model"] = check_index_model
+    COMMANDS["create-index-model"] = create_index_model
+except ImportError as ex:
+    if os.environ.get("USE_NMSLIB", "0") == "1":
+        logger.warning(
+            "nmslib not available, to install nmslib,"
+            " run `pip install nmslib`."
+        )
+        raise ex
 
 
 def build_parser() -> ArgumentParser:
     parser = ArgumentParser(
         "catalyst-contrib", formatter_class=RawTextHelpFormatter
     )
-    all_commands = ', \n'.join(map(lambda x: f"    {x}", COMMANDS.keys()))
+    all_commands = ", \n".join(map(lambda x: f"    {x}", COMMANDS.keys()))
 
     subparsers = parser.add_subparsers(
         metavar="{command}",
