@@ -1,16 +1,24 @@
-from collections import OrderedDict
 from argparse import ArgumentParser, RawTextHelpFormatter
+from collections import OrderedDict
 
-from .scripts import run, make_report
+from catalyst.__version__ import __version__
+from catalyst.dl.scripts import init, run, trace
 
-COMMANDS = OrderedDict([("run", run), ("make-report", make_report)])
+COMMANDS = OrderedDict([
+    ("init", init),
+    ("run", run),
+    ("trace", trace),
+])
 
 
 def build_parser() -> ArgumentParser:
     parser = ArgumentParser(
         "catalyst-dl", formatter_class=RawTextHelpFormatter
     )
-    all_commands = ', \n'.join(map(lambda x: f"    {x}", COMMANDS.keys()))
+    parser.add_argument(
+        "-v", "--version", action="version", version=f"%(prog)s {__version__}"
+    )
+    all_commands = ", \n".join(map(lambda x: f"    {x}", COMMANDS.keys()))
 
     subparsers = parser.add_subparsers(
         metavar="{command}",
