@@ -1,15 +1,15 @@
-from collections import OrderedDict
 from argparse import ArgumentParser, RawTextHelpFormatter
+from collections import OrderedDict
 
-from .offpolicy.scripts import dump_redis, load_redis, \
-    run_samplers, run_trainer
+from catalyst.__version__ import __version__
+from catalyst.rl.scripts import dump_db, load_db, run_samplers, run_trainer
 
 COMMANDS = OrderedDict(
     [
         ("run-trainer", run_trainer),
         ("run-samplers", run_samplers),
-        ("dump-redis", dump_redis),
-        ("load-redis", load_redis),
+        ("dump-db", dump_db),
+        ("load-db", load_db),
     ]
 )
 
@@ -18,7 +18,10 @@ def build_parser() -> ArgumentParser:
     parser = ArgumentParser(
         "catalyst-rl", formatter_class=RawTextHelpFormatter
     )
-    all_commands = ', \n'.join(map(lambda x: f"    {x}", COMMANDS.keys()))
+    parser.add_argument(
+        "-v", "--version", action="version", version=f"%(prog)s {__version__}"
+    )
+    all_commands = ", \n".join(map(lambda x: f"    {x}", COMMANDS.keys()))
 
     subparsers = parser.add_subparsers(
         metavar="{command}",
