@@ -1,19 +1,24 @@
-import logging
 import base64
+import logging
+import os
+
 import numpy as np
 from six import string_types
-from .serialization import serialize, deserialize
+
+from .serialization import deserialize, serialize
 
 logger = logging.getLogger(__name__)
 
 try:
     import lz4.frame
     LZ4_ENABLED = True
-except ImportError:
-    logger.warning(
-        "lz4 not available, disabling compression. "
-        "To install lz4, run `pip install lz4`."
-    )
+except ImportError as ex:
+    if os.environ.get("USE_LZ4", "0") == "1":
+        logger.warning(
+            "lz4 not available, disabling compression. "
+            "To install lz4, run `pip install lz4`."
+        )
+        raise ex
     LZ4_ENABLED = False
 
 
@@ -47,3 +52,15 @@ def decompress_if_needed(data):
     if is_compressed(data):
         data = decompress(data)
     return data
+
+
+if LZ4_ENABLED:
+    pack = compress
+    pack_if_needed = compress_if_needed
+    unpack = decompress
+    unpack_if_needed = decompress_if_needed
+else:
+    pack = serialize
+    pack_if_needed = serialize
+    unpack = deserialize
+    unpack_if_needed = deserialize
