@@ -1,8 +1,12 @@
 # flake8: noqa
 import argparse
-import pytest
+import io
+import json
 
-from .. import config
+import numpy as np
+
+from catalyst import utils
+from catalyst.utils import config
 
 
 def test_parse_config_args():
@@ -27,7 +31,7 @@ def test_parse_config_args():
         ]
     )
 
-    configuration, args = config.parse_config_args(
+    configuration, args = utils.parse_config_args(
         config=configuration, args=args, unknown_args=uargs
     )
 
@@ -45,3 +49,25 @@ def test_parse_config_args():
         v = configuration["args"].get(key)
         assert v is not None
         assert v == value
+
+
+def test_parse_numbers():
+    configuration = {
+        "a": 1,
+        "b": 20,
+        "c": 303e5,
+        "d": -4,
+        "e": -50,
+        "f": -666e7,
+        "g": 0.35,
+        "h": 7.35e-5,
+        "k": 8e-10,
+    }
+
+    buffer = io.StringIO()
+    json.dump(configuration, buffer)
+    buffer.seek(0)
+    yaml_config = config._load_ordered_yaml(buffer)
+
+    for key, item in configuration.items():
+        assert np.isclose(yaml_config[key], item)
